@@ -1,6 +1,6 @@
 use utf8;
 package CatalystX::InjectModule::MI;
-$CatalystX::InjectModule::MI::VERSION = '0.18';
+$CatalystX::InjectModule::MI::VERSION = '0.19';
 # This plugin is inspired by :
 # - CatalystX::InjectComponent
 # - Catalyst::Plugin::AutoCRUD
@@ -389,6 +389,11 @@ sub _load_lib {
     foreach my $file (@$all_libs) {
 
         next if grep {/TraitFor/} $file;
+
+        my $app_name = $self->ctx->config->{name};
+        die "A file of the module " . $module->{name} ." contains the name of the application ($app_name), which is to be avoided otherwise the components can be loaded without this being desired\nfile: $file\n"
+          if ( grep {/$app_name\/Model\/|$app_name\/View\/|$app_name\/Controller\//} $file );
+
         $self->_load_component( $module, $file )
           if ( grep {/\/Model\/|\/View\/|\/Controller\//} $file );
 
@@ -637,7 +642,7 @@ CatalystX::InjectModule::MI Catalyst Module injector
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
